from setuptools import setup

setup(name='ftThanos',
version="0.0.86",
description="A client for 86 API",
author="Thanos 86",
author_email="thanos@86paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
